@@ -1,3 +1,5 @@
+from hotdog.Config import GetConfig
+
 from appium_selector.CapGenerators.Caps import Caps
 
 
@@ -23,8 +25,13 @@ class SauceWeb(Caps):
         self.options['mustard'] = mustard
         self.options['deviceName'] = self.displayString()
 
+        try:
+            self.caps['parentTunnel'] = GetConfig('SAUCE_PARENT_TUNNEL')
+        except:
+            pass
         self.caps['platform'] = self.env.find('platformName').text
         self.caps['browserName'] = self.env.find('browserName').text
         self.caps['version'] = self.env.find('version').text
         self.caps['udid'] = "%s-%s-%s" % (self.env.find('platformName').text.replace('.',''), self.env.find('browserName').text.replace('.',''), self.env.find('version').text.replace('.',''))
+
         return {'desiredCaps': self.caps, 'options': self.options}
