@@ -171,7 +171,7 @@ class DeviceSelector:
             #mobileNodes = self.grid.mobileNodes
             if self.platform:
                 if self.platform == 'desktop':
-                    nodes = self.grid.webNodes + self.sauce.webNodes + self.sauce.mobileWebNodes
+                    nodes = self.grid.webNodes + self.sauce.webNodes + self.sauce.mobileWebNodes + self.local.webNodes
                 elif self.platform == 'mobile':
                     nodes = self.grid.mobileNodes + self.sauce.mobileNodes
                 else:
@@ -193,7 +193,8 @@ class DeviceSelector:
             output = []
             for x in range(len(self.devices)):
                 dc = self.devices[x].desiredCaps(mustard=self.mustard)
-                output.append(dc)
+                if dc not in output:
+                    output.append(dc)
             return output
 
     def _saveDevicesDesktop(self):
